InvokerState enum

Expand / collapse behavior for the floating invoker.

alwaysOpened: always shows the full bubble (still draggable / hidable).

collapsible: starts collapsed as an edge peek; tap or drag outward to expand; tap when expanded opens Infospect; swipe inward to collapse.

autoCollapse: like collapsible, but auto-collapses 5 seconds after expand.

Inheritance
Available extensions

Values

alwaysOpened → const InvokerState
collapsible → const InvokerState
autoCollapse → const InvokerState

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InvokerState>
A constant List of the values in this enum, in order of their declaration.