InfospectDesktopMenuActions class

Shared menu / shortcut actions for the Infospect desktop window.

Constructors

InfospectDesktopMenuActions({required BuildContext context, required Infospect infospect, required NetworksListNotifier networks, required LogsListNotifier logs})

Properties

context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
infospect Infospect
final
logs LogsListNotifier
final
networks NetworksListNotifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutBindings Map<ShortcutActivator, VoidCallback>
no setter

Methods

buildNativeMenus({void runGuarded(VoidCallback action)?}) List<PlatformMenuItem>
Kept for tests / hosts that want the same menu model as a PlatformMenuBar.
clearLogs() → void
clearNetwork() → void
closeWindow() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBreakpoints() → void
popOutLogs() → void
popOutNetwork() → void
selectLogs() → void
selectNetwork() → void
shareLogs() → void
shareNetwork() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited