InfospectDesktopShortcuts class abstract final

Keyboard shortcuts used by the Infospect desktop layout and host invoker.

Activators use ⌘ on Apple platforms and Ctrl elsewhere. Host apps that open Infospect use openInspectorActivators (⌘⌥I / Ctrl+Alt+I).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

breakpoints SingleActivator
no setter
breakpointsLabel String
no setter
clearLogs SingleActivator
no setter
clearLogsLabel String
no setter
clearNetwork SingleActivator
no setter
clearNetworkLabel String
no setter
closeWindow SingleActivator
no setter
closeWindowLabel String
no setter
isApple bool
no setter
logsTab SingleActivator
no setter
logsTabLabel String
no setter
networkTab SingleActivator
no setter
networkTabLabel String
no setter
openInspectorActivators List<SingleActivator>
no setter
openInspectorLabel String
no setter
popOutLogs SingleActivator
no setter
popOutLogsLabel String
no setter
popOutNetwork SingleActivator
no setter
popOutNetworkLabel String
no setter
shareLogs SingleActivator
no setter
shareLogsLabel String
no setter
shareNetwork SingleActivator
no setter
shareNetworkLabel String
no setter

Static Methods

primary(LogicalKeyboardKey key, {bool shift = false, bool alt = false}) SingleActivator
Primary modifier activator (⌘ on macOS, Ctrl on Windows/Linux).
primaryLabel(String key, {bool shift = false, bool alt = false}) String