InfospectDesktopTab enum
Desktop inspector tabs that can be shown in the main window or popped out.
Values
- network → const InfospectDesktopTab
-
const InfospectDesktopTab(0, 'Network calls') - logs → const InfospectDesktopTab
-
const InfospectDesktopTab(1, 'Logs')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabIndex → int
-
Matches NavigationTabData.tabs ordering.
final
- windowTitle → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromTabIndex(
int tabIndex) → InfospectDesktopTab?
Constants
-
values
→ const List<
InfospectDesktopTab> - A constant List of the values in this enum, in order of their declaration.