InfospectBreakpointMatchContext class

Snapshot used when evaluating breakpoint conditions.

Constructors

InfospectBreakpointMatchContext({required String method, required String endpoint, Map<String, dynamic> queryParameters = const <String, dynamic>{}, Map<String, dynamic> requestHeaders = const <String, dynamic>{}, dynamic requestBody, int? statusCode, dynamic responseBody, Map<String, dynamic> responseHeaders = const <String, dynamic>{}, bool isResponsePhase = false})
const

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
isResponsePhase bool
final
method String
final
queryParameters Map<String, dynamic>
final
requestBody → dynamic
final
requestHeaders Map<String, dynamic>
final
responseBody → dynamic
final
responseHeaders Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited