InfospectBreakpointMatchOp enum

How a condition compares the observed value.

Inheritance
Available extensions

Values

exists → const InfospectBreakpointMatchOp

Key / JSON path exists (value ignored).

equals → const InfospectBreakpointMatchOp

Exact string equality (case-sensitive for bodies/params; status is numeric).

contains → const InfospectBreakpointMatchOp

Case-sensitive substring / containment.

inRange → const InfospectBreakpointMatchOp

Status code inclusive range; InfospectBreakpointCondition.value like 200-299.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InfospectBreakpointMatchOp>
A constant List of the values in this enum, in order of their declaration.