InfospectBreakpointMatchTarget enum

What part of a network call a breakpoint condition inspects.

Inheritance
Available extensions

Values

queryParam → const InfospectBreakpointMatchTarget

Query / URL parameter (key required).

requestHeader → const InfospectBreakpointMatchTarget

Request header (key required).

requestBodyText → const InfospectBreakpointMatchTarget

Raw request body text (no key).

requestBodyJson → const InfospectBreakpointMatchTarget

JSON request body at dotted path (key = path, e.g. user.id).

responseStatus → const InfospectBreakpointMatchTarget

HTTP response status code (no key; value is 200 or 200-299).

responseBodyText → const InfospectBreakpointMatchTarget

Raw response body text (no key).

responseBodyJson → const InfospectBreakpointMatchTarget

JSON response body at dotted path (key = path).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InfospectBreakpointMatchTarget>
A constant List of the values in this enum, in order of their declaration.