InfospectBreakpointPayload class

Editable snapshot shown in the breakpoint dialog / window.

Constructors

InfospectBreakpointPayload({required String method, required String uri, required String endpoint, Map<String, String> headers = const <String, String>{}, Map<String, String> queryParameters = const <String, String>{}, String body = '', int? statusCode})
const

Properties

body String
final
endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
queryParameters Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
Response status code (only meaningful for InfospectBreakpointPhase.response).
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uri String
final

Methods

copyWith({String? method, String? uri, String? endpoint, Map<String, String>? headers, Map<String, String>? queryParameters, String? body, int? statusCode, bool clearStatusCode = false}) InfospectBreakpointPayload
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited