InfospectBreakpointResult class

Result returned when the user finishes (or dismisses) a breakpoint editor.

Properties

aborted bool
When true, the call should be cancelled instead of continuing.
final
hashCode int
The hash code for this object.
no setterinherited
payload InfospectBreakpointPayload
Edited payload to apply when aborted is false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited