JsonBracketMatch class

Matching brace/bracket pair indexes (inclusive character positions).

Constructors

JsonBracketMatch({required int open, required int close})
const

Properties

close int
final
hashCode int
The hash code for this object.
no setterinherited
open int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited