JsonParseIssue class
Location of a JSON syntax problem inside editor text.
Constructors
- JsonParseIssue({required int offset, required int length, required String message})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited