InfospectNetworkCall class

Represents an Network call data for the Infospect application.

Available extensions

Constructors

InfospectNetworkCall(int id, {DateTime? time, String endpoint = '', String client = '', bool loading = true, bool secure = false, String method = '', String server = '', String uri = '', int duration = 0, InfospectNetworkRequest? request, InfospectNetworkResponse? response, InfospectNetworkError? error, bool hadRequestBreakpoint = false, bool hadResponseBreakpoint = false, bool requestEditedAtBreakpoint = false, bool responseEditedAtBreakpoint = false, InfospectBreakpointEdit? requestBreakpointEdit, InfospectBreakpointEdit? responseBreakpointEdit})
Creates an instance of the InfospectNetworkCall class.
InfospectNetworkCall.fromJson(String source)
factory
InfospectNetworkCall.fromMap(dynamic map)
factory

Properties

client String
The client information associated with the Network call.
final
createdTime DateTime
The timestamp when the Network call was created.
final
cURL String

Available on InfospectNetworkCall, provided by the NetworkCallExtension extension

Generates a cURL command string based on the Network request data associated with the call.
no setter
duration int
The duration of the Network call in milliseconds.
final
endpoint String
The endpoint (URL path) used in the Network call.
final
error InfospectNetworkError?
The Network error data associated with the call (if any).
final
hadRequestBreakpoint bool
Whether a request breakpoint paused this call.
final
hadResponseBreakpoint bool
Whether a response breakpoint paused this call.
final
hasBreakpointTrace bool
True when any breakpoint interacted with this call.
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
The unique identifier for the Network call.
final
loading bool
A flag indicating if the call is still in progress (loading) or completed.
final
method String
The Network method used in the call (e.g., GET, POST, etc.).
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
request InfospectNetworkRequest?
The Network request data associated with the call.
final
requestBreakpointEdit InfospectBreakpointEdit?
Original vs edited request snapshot when a request breakpoint applied.
final
requestEditedAtBreakpoint bool
Whether the request was modified at a breakpoint before sending.
final
response InfospectNetworkResponse?
The Network response data associated with the call.
final
responseBreakpointEdit InfospectBreakpointEdit?
Original vs edited response snapshot when a response breakpoint applied.
final
responseEditedAtBreakpoint bool
Whether the response was modified at a breakpoint before delivery.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secure bool
A flag indicating if the call is made over a secure (NetworkS) connection.
final
server String
The server URL (domain) to which the call is made.
final
sharableData Future<String>

Available on InfospectNetworkCall, provided by the NetworkCallExtension extension

no setter
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uri String
The full URI (server + endpoint) used in the Network call.
final

Methods

copyWith({int? id, DateTime? createdTime, String? client, bool? loading, bool? secure, String? method, String? endpoint, String? server, String? uri, int? duration, InfospectNetworkRequest? request, InfospectNetworkResponse? response, InfospectNetworkError? error, bool? hadRequestBreakpoint, bool? hadResponseBreakpoint, bool? requestEditedAtBreakpoint, bool? responseEditedAtBreakpoint, InfospectBreakpointEdit? requestBreakpointEdit, InfospectBreakpointEdit? responseBreakpointEdit}) InfospectNetworkCall
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited