requestEditedAtBreakpoint property
Whether the request was modified at a breakpoint before sending.
Implementation
final bool requestEditedAtBreakpoint;
Whether the request was modified at a breakpoint before sending.
final bool requestEditedAtBreakpoint;