responseEditedAtBreakpoint property
Whether the response was modified at a breakpoint before delivery.
Implementation
final bool responseEditedAtBreakpoint;
Whether the response was modified at a breakpoint before delivery.
final bool responseEditedAtBreakpoint;