InfospectLogHelper class
InfospectLogHelper is a utility class designed to assist Infospect in handling logging tasks.
This class acts as an intermediary between Infospect and its logger, encapsulating
the logic for adding logs, aggregating multiple logs, and clearing all logs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addLog(
InfospectLog log) → void -
Adds a single
InfospectLogentry to the logger of theInfospectinstance. -
addLogs(
List< InfospectLog> logs) → void -
Aggregates and adds multiple
InfospectLogentries to the logger of theInfospectinstance. -
clearAllLogs(
) → void -
Clears all the logs from the logger of the
Infospectinstance. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited