addLog method
Adds a single InfospectLog entry to the logger of the Infospect instance.
log: The log entry to be added.
Implementation
void addLog(InfospectLog log) {
_infospect.infospectLogger.add(log);
}
Adds a single InfospectLog entry to the logger of the Infospect instance.
log: The log entry to be added.void addLog(InfospectLog log) {
_infospect.infospectLogger.add(log);
}