InfospectMobileChrome class abstract final

Shared mobile chrome sizes for Infospect list / pushed screens.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

backIconSize → const double
backTapTarget → const Size
titleFontSize → const double
toolbarHeight → const double
toolbarPadding → const EdgeInsets