InfospectShare class

Safe sharing for Infospect.

On macOS multi-view apps (multiview_desktop), share_plus force-unwraps registrar.view, which is nil and crashes the process. Those platforms use Finder / clipboard fallbacks instead.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

shareFiles(List<XFile> files, {String? subject, Rect? sharePositionOrigin, BuildContext? context}) Future<void>
shareText(String text, {String? subject, Rect? sharePositionOrigin, BuildContext? context}) Future<void>