ActionModel<T> class

Constructors

ActionModel({required IconData icon, required List<PopupAction<T>> actions, String? title})

Properties

actions → List<PopupAction<T>>
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited