LaunchNotifier class
Notifier responsible for handling the state of the application's launch phase, especially related to tab changes.
This replaces the previous BLoC implementation with a simple ValueNotifier.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
int> - LaunchNotifier
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedTab → int
-
Gets the currently selected tab index.
no setter
- value ↔ int
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
selectTab(
int index) → void - Selects a tab by its index.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LaunchNotifier
-
Gets the singleton instance of LaunchNotifier.
no setter