InfospectBreakpointManager class

Manages breakpoint rules and resolves the first matching rule for a call.

Properties

breakpoints ValueNotifier<List<InfospectNetworkBreakpoint>>
final
hashCode int
The hash code for this object.
no setterinherited
pendingCount ValueNotifier<int>
Pending intercept sessions waiting for user action (debug / UI).
final
rules List<InfospectNetworkBreakpoint>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBreakpoint(InfospectNetworkBreakpoint breakpoint) → void
clearBreakpoints() → void
completePending(String sessionId, InfospectBreakpointResult result) bool
dispose() → void
findMatch(InfospectBreakpointMatchContext context) InfospectNetworkBreakpoint?
Returns the first enabled rule that matches context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerPending(String sessionId) Completer<InfospectBreakpointResult>
Creates a pending session completer tracked by sessionId.
removeBreakpoint(String id) → void
setEnabled(String id, bool enabled) → void
toString() String
A string representation of this object.
inherited
updateBreakpoint(InfospectNetworkBreakpoint breakpoint) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

newId() String
parseBody(String body) → dynamic
Parses editor body text back into a JSON value when possible.
stringifyBody(dynamic body) String
Pretty-prints body for the editor when possible.
stringifyMap(Map<String, dynamic>? source) Map<String, String>