InfospectBreakpointPresenter class
Presents request/response breakpoint editors (compact sheet on mobile, native desktop window on desktop).
Desktop intercept windows are cached by session id so opening another window (which rebuilds every multiview builder) does not wipe in-progress edits. Multiple concurrent intercept windows are supported.
Constructors
- InfospectBreakpointPresenter(Infospect _infospect)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
present(
{required InfospectBreakpointPhase phase, required InfospectBreakpointPayload payload}) → Future< InfospectBreakpointResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited