InfospectBreakpointCondition class
One AND-combined filter on top of endpoint / method matching.
Constructors
- InfospectBreakpointCondition({required String id, required InfospectBreakpointMatchTarget target, required InfospectBreakpointMatchOp op, String? key, String? value})
-
const
-
InfospectBreakpointCondition.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isResponseOnly → bool
-
no setter
- key → String?
-
Param name, header name, or JSON path. Unused for status / body-text.
final
- op → InfospectBreakpointMatchOp
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - summary → String
-
Human-readable summary for list chips.
no setter
- target → InfospectBreakpointMatchTarget
-
final
- value → String?
-
Expected value, substring, or status / range (
404,500-599).final
Methods
-
copyWith(
{String? id, InfospectBreakpointMatchTarget? target, InfospectBreakpointMatchOp? op, String? key, String? value, bool clearKey = false, bool clearValue = false}) → InfospectBreakpointCondition -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited