InfospectBreakpointEdit class
Stores the original and edited payloads for a single breakpoint phase.
Constructors
- InfospectBreakpointEdit({required InfospectBreakpointPayload original, required InfospectBreakpointPayload edited})
-
const
-
InfospectBreakpointEdit.fromMap(Map<
String, dynamic> map) -
factory
Properties
- bodyChanged → bool
-
no setter
- edited → InfospectBreakpointPayload
-
final
- hasChanges → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headersChanged → bool
-
no setter
- methodChanged → bool
-
no setter
- original → InfospectBreakpointPayload
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- queryChanged → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusChanged → bool
-
no setter
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - urlChanged → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited