TopicDetailsBodyJson class
JSON request/response body with beautify, foldable tree, and open-in-window.
- Inheritance
-
- Object
- TopicDetailsBody
- TopicDetailsBodyJson
Constructors
-
TopicDetailsBodyJson({required Map<
String, dynamic> json, required InfospectNetworkCall call, required NetworkBodyKind kind, String windowTitle = 'Body'})
Properties
- call → InfospectNetworkCall
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
json
→ Map<
String, dynamic> -
final
- kind → NetworkBodyKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- windowTitle → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited