Infospect class
Infospect is a utility class designed to facilitate monitoring and debugging activities,
such as logging network calls, navigating within the app, managing multi-window actions,
and handling application logs.
Properties
- brightness → Brightness
-
no setter
- context → BuildContext?
-
no setter
- dioInterceptor → InfospectDioInterceptor
-
interceptors
no setter
-
get the navigator key
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- infospectLogger → InfospectLogger
-
final
-
isInfospectOpened
↔ ValueNotifier<
bool> -
getter/setter pair
- maxCallsCount → int
-
parameters
final
-
networkCallsSubject
→ BehaviorSubject<
List< InfospectNetworkCall> > -
final
-
final
-
final
-
poppedOutDesktopTabs
→ ValueListenable<
Set< InfospectDesktopTab> > -
Tabs currently shown in their own desktop windows (removed from the main
Infospect sidebar until those windows close).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addCall(
InfospectNetworkCall call) → void - Network calls
-
addError(
InfospectNetworkError error, int requestId) → void -
addHttpCall(
InfospectNetworkCall httpCall) → void -
addLog(
InfospectLog log) → void -
Logs an instance of
InfospectLog. -
addLogs(
List< InfospectLog> logs) → void -
addResponse(
InfospectNetworkResponse response, int requestId) → void -
clearAllLogs(
) → void -
clearAllNetworkCalls(
) → void -
dispose(
) → void - Dispose subjects and subscriptions
-
focusPoppedOutDesktopTab(
InfospectDesktopTab tab) → Future< void> - Focuses an already-open popped-out tab window, if any.
-
handleMainWindowReceiveData(
) → void -
handleMultiWindowReceivedData(
BuildContext context) → void -
httpClientInterceptor(
{required Client client}) → InfospectHttpClientInterceptor -
infospectLaunchScreen(
{required NetworksListNotifier networksListNotifier, required LogsListNotifier logsListNotifier}) → Widget - get the launch screen widget
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openInspectorInNewWindow(
) → Future< void> - Navigates to the interceptor.
-
openNetworkBodyInNewWindow(
{required InfospectNetworkCall call, required NetworkBodyKind kind, bool detailsInitiallyExpanded = false}) → Future< void> - Opens a network call body with request metadata in a new desktop window.
-
openRawDataInNewWindow(
{required Map< String, dynamic> data, String title = 'Body', bool beautificationRequired = true}) → Future<void> - Opens JSON / raw data (e.g. headers) in a new desktop window.
-
popOutDesktopTab(
InfospectDesktopTab tab) → Future< void> -
Opens
tabin a separate desktop window and removes it from the main Infospect window sidebar. -
run(
List< String> args, {required Widget myApp}) → void - run app
-
sendLogs(
[List< InfospectLog> ? logs]) → void -
sendNetworkCalls(
) → void - No-ops kept for API compatibility with 0.1.x.
-
sendThemeMode(
{required bool isDarkTheme}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkInstance(
Infospect? instance) → Infospect -
Checks if the
Infospectinstance is initialized and throws an error -
ensureInitialized(
{int maxCallsCount = 1000, bool logAppLaunch = false, }) → Infospect -
Ensures the
Infospectinstance is initialized. If it's not initialized, it will initialize it with the provided arguments.