InfospectNavigationHelper class
InfospectNavigationHelper aids the Infospect class in navigation and window management tasks.
This class provides functionalities to open new windows (useful in a desktop environment),
navigate to certain screens, and handle the launching of the app.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkTheme → bool
-
Determines whether the current theme mode is dark.
no setter
- mobileRoutes → MobileRoutes
-
final
-
poppedOutTabs
→ ValueNotifier<
Set< InfospectDesktopTab> > -
Tabs currently shown in their own windows (removed from the main sidebar).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
focusPoppedOutDesktopTab(
InfospectDesktopTab tab) → Future< void> - Focuses an already-open popped-out tab window, if any.
-
interceptorScreen(
{bool isDarkTheme = true, bool wrapInMaterialApp = false}) → Widget - Provides the main widget for the interceptor screen.
- Navigates to the interceptor screen.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openInspectorInNewWindow(
) → Future< void> - Opens the inspector in a new window (applicable only on desktop platforms).
-
openNetworkBodyInNewWindow(
{required InfospectNetworkCall call, required NetworkBodyKind kind, bool detailsInitiallyExpanded = false}) → Future< void> - Opens a network call body (with request metadata) in a new desktop window.
-
openRawDataInNewWindow(
{required Map< String, dynamic> data, String title = 'Body', bool beautificationRequired = true}) → Future<void> - Opens raw / JSON map data in a new desktop window (headers, etc.).
-
popOutDesktopTab(
InfospectDesktopTab tab) → Future< void> -
Opens
tabin a separate window and removes it from the main Infospect UI. -
run(
List< String> args, {required Widget myApp}) → void - Initiates the app.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited