infospect library

Classes

AppBarActionWidget<T>
App-bar action that opens a native-feeling filter or overflow menu.
AppBottomBar
Backward-compatible alias for AppSegmentedTabBar.
AppDivider
AppSearchBar
AppSegmentedTabBar
Compact top segmented tab strip used by the mobile Infospect shell.
ConditionalWidget
HighlightText
A widget that displays text with a highlighted section.
Infospect
Infospect is a utility class designed to facilitate monitoring and debugging activities, such as logging network calls, navigating within the app, managing multi-window actions, and handling application logs.
InfospectDesktopInvoker
InfospectInvoker
Floating Infospect entry point overlaid on child.
InfospectLog
Represents a log entry for the Infospect application.
InfospectLogHelper
InfospectLogHelper is a utility class designed to assist Infospect in handling logging tasks. This class acts as an intermediary between Infospect and its logger, encapsulating the logic for adding logs, aggregating multiple logs, and clearing all logs.
InfospectNavigationHelper
InfospectNavigationHelper aids the Infospect class in navigation and window management tasks. This class provides functionalities to open new windows (useful in a desktop environment), navigate to certain screens, and handle the launching of the app.
InfospectNetworkCallHelper
InfospectNetworkCallHelper is a utility class tailored to assist Infospect in handling network-related tasks. It provides methods to log network calls, errors, responses and facilitates integration with interceptors for networking libraries like Dio and HttpClient.
InfospectTheme

Enums

InfospectDesktopTab
Desktop inspector tabs that can be shown in the main window or popped out.
InvokerEdge
Screen edge the invoker can dock to.
InvokerState
Expand / collapse behavior for the floating invoker.

Typedefs

BottomBarItem = ({IconData icon, IconData selectedIcon, String title})