InfospectToast class
Compact feedback toast.
On desktop, shows a top-right floating notification (native-app style). On mobile / web, falls back to a short floating SnackBar.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, String message, {Duration duration = const Duration(seconds: 2), IconData? icon}) → void -
Shows
messageusing a desktop toast or mobile snackbar.